
# Slot: mesh terms


mesh terms tagging a publication

URI: [biolink:mesh_terms](https://w3id.org/biolink/vocab/mesh_terms)


## Domain and Range

[Publication](Publication.md) &#8594;  <sub>0..\*</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [Article](Article.md)
 * [Book](Book.md)
 * [BookChapter](BookChapter.md)
 * [Publication](Publication.md)
 * [Serial](Serial.md)
